"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.spawn = exports.execute = exports.shellExec = void 0;

var _child_process = require("child_process");

var _stringio = require("@rauschma/stringio");

var _print = require("./print");

const shellExec = async cmd => new Promise((resolve, reject) => {
  (0, _child_process.exec)(cmd, (err, stdout, stderr) => {
    if (err) {
      reject(err);
    } else {
      resolve({
        stdout,
        stderr
      });
    }
  });
});

exports.shellExec = shellExec;

const execute = async (cmd, cmdInfo, throwOnError = false) => {
  try {
    (0, _print.printInfo)(cmdInfo);
    const result = await shellExec(cmd);
    (0, _print.printSuccess)(result.stdout);
    (0, _print.printError)(result.stderr);
  } catch (err) {
    (0, _print.printError)(err);

    if (throwOnError) {
      throw new Error(err);
    }
  }
};

exports.execute = execute;

const spawn = async (cmd, cmdInfo, args, stdio = [process.stdin, process.stdout, process.stderr]) => {
  (0, _print.printInfo)(cmdInfo);
  const childProcess = (0, _child_process.spawn)(cmd, args, {
    stdio
  });

  if (childProcess.stdout) {
    childProcess.stdout.on('data', data => {
      (0, _print.printSuccess)(data);
    });
  }

  if (childProcess.stderr) {
    childProcess.stdout.on('data', data => {
      (0, _print.printError)(data);
    });
  }

  await (0, _stringio.onExit)(childProcess);
};

exports.spawn = spawn;