"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.fetch = exports.createResponseError = void 0;

var _nodeFetch = _interopRequireDefault(require("node-fetch"));

var _print = require("./print");

var _httpCodes = require("./http-codes");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const createResponseError = (message, code) => {
  const error = new Error(message);
  error.code = code;
  error.message = message;
  return error;
}; // eslint-disable-next-line


exports.createResponseError = createResponseError;

const fetch = async (url, method, body, token = null, type = null, throwOnError = false) => {
  try {
    (0, _print.printInfo)(`Attempting to ${method} ${body} to ${url} ...`);
    const response = await (0, _nodeFetch.default)(url, {
      method,
      headers: {
        ['Content-Type']: type ? type : undefined,
        Authorization: token ? `bearer ${token}` : undefined
      },
      body
    });

    if (response.status === _httpCodes.HTTP_OK || response.status === _httpCodes.HTTP_OK_ALT) {
      (0, _print.printSuccess)(`${method} to ${url} Successful`);
      return response;
    }

    throw createResponseError(`${method} to ${url} responded with ${response.status}`, response.status);
  } catch ({
    message,
    code
  }) {
    (0, _print.printError)(`${code} ${message}`);

    if (throwOnError) {
      throw createResponseError(message, code);
    }
  }
};

exports.fetch = fetch;