"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.initializePackageManager = void 0;

var _resources = require("../resources");

var _print = require("../print");

var _exec = require("../exec");

var _utils = require("./utils");

/* eslint no-console: 0 */
const getNpmInitJson = async () => {
  try {
    const {
      stdout,
      stderr
    } = await (0, _exec.shellExec)(`npm init -y --force`);
    const outputstring = stdout.replace(`Wrote to ${process.cwd()}/package.json:\n\n`, '');

    if (stderr.includes('npm WARN using --force')) {
      (0, _print.printWarning)(stderr);
    } else if (stderr) {
      (0, _print.printError)(stderr);
    }

    return JSON.parse(outputstring);
  } catch (err) {
    (0, _print.printError)(err);
    throw new Error(err);
  }
};

const initializePackageManager = // eslint-disable-next-line
async (pkgManager, projectName, orgScope, projectDescription, repoOwner) => {
  if (pkgManager === 'npm') {
    const scopedProject = (0, _utils.getScopedProject)(orgScope, projectName);
    const pkg = await getNpmInitJson();
    const newPkg = (0, _utils.updatePackageWithInfo)(pkg, scopedProject, (0, _utils.parseDescription)(projectDescription, projectName), repoOwner, projectName); // eslint-disable-next-line

    const json = JSON.stringify(newPkg, null, 4);
    (0, _resources.addCustomResource)('package.json', json);
    (0, _print.printSuccess)('------ Wrote NPM package.json ------');
    (0, _print.printSuccess)(json);
  }
};

exports.initializePackageManager = initializePackageManager;