"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _path = require("path");

var _plugin = _interopRequireDefault(require("react-entry-loader/plugin"));

var _entry = _interopRequireDefault(require("react-entry-loader/entry"));

var _copyWebpackPlugin = _interopRequireDefault(require("copy-webpack-plugin"));

var _miniCssExtractPlugin = _interopRequireDefault(require("mini-css-extract-plugin"));

var _middleware = _interopRequireDefault(require("@storybook/core/dist/server/middleware"));

var _config = require("./build/config");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/* eslint-env node */

/* eslint no-console: 0 */
var _default = () => {
  const isProduction = _config.nodeEnv === 'production';
  const appUrl = _config.deployUrl;
  console.log(`
    Running webpack with config from '.build/config.json':
    NODE_ENV=${_config.nodeEnv}
    version=${_config.version}
    app-url=${appUrl}
  `);
  return {
    mode: isProduction ? 'production' : 'development',
    entry: {
      app: ['@babel/polyfill', (0, _entry.default)({
        output: 'index.html',
        appUrl,
        version: _config.version
      })('./src/index.html.js')],
      silent: ['@babel/polyfill', (0, _entry.default)({
        output: 'silent_renew.html'
      })('./src/silent_renew.html.js')]
    },
    output: {
      path: (0, _path.resolve)(__dirname, 'build/pkg'),
      filename: '[name]-[contenthash].js',
      // improve paths in devtools
      devtoolModuleFilenameTemplate: info => `webpack:///${(0, _path.relative)(__dirname, info.absoluteResourcePath)}`
    },
    optimization: {
      minimize: isProduction,
      runtimeChunk: {
        name: 'runtime'
      },
      splitChunks: {
        chunks: 'all',
        name: !isProduction,
        cacheGroups: {
          default: false,
          react: {
            test: /[\\/]node_modules[\\/]react/,
            name: 'react',
            chunks: 'all'
          }
        }
      }
    },
    plugins: [new _plugin.default(), new _copyWebpackPlugin.default([{
      from: 'src/share-img.png'
    }]), new _copyWebpackPlugin.default([{
      from: 'src/favicon.png'
    }]), new _miniCssExtractPlugin.default({
      chunkFilename: '[name]-[contenthash].css'
    })],
    module: {
      // Suppress warnings from Cesium which uses dynamic 'require'
      unknownContextCritical: false,
      rules: [{
        test: /(\.scss|\.css)$/,
        use: [_miniCssExtractPlugin.default.loader, {
          loader: 'css-loader',
          options: {
            modules: false,
            sourceMap: !isProduction,
            importLoaders: 2,
            localIdentName: '[name]',
            camelCase: true
          }
        }, {
          loader: 'postcss-loader',
          options: {
            plugins: () => [require('postcss-nested')({
              /* options */
            }), require('autoprefixer')],
            sourceMap: !isProduction
          }
        }, {
          loader: 'sass-loader',
          options: {
            sourceMap: !isProduction,
            // adds app-theme overrides to component's custom themes
            // data: '@import "src/app.theme.scss";',
            includePaths: [(0, _path.resolve)(__dirname), (0, _path.resolve)(__dirname, './node_modules')]
          }
        }]
      }, {
        test: /\.(png|jpg|jpeg|svg|ico|gif|ttf|eot|woff|woff2)$/,
        loader: 'url-loader?limit=10000'
      }, {
        test: /\.jsx?$/,
        include: [(0, _path.resolve)(__dirname, 'node_modules/react-entry-loader'), (0, _path.resolve)(__dirname, 'node_modules/refocus'), (0, _path.resolve)(__dirname, 'src')],
        loader: 'babel-loader',
        options: {
          // making sure babel gets the right environment and thus
          // picks up the correct config.
          envName: _config.nodeEnv
        }
      }]
    },
    devtool: isProduction ? false : '#cheap-module-source-map',
    devServer: {
      port: 8080,
      host: '0.0.0.0',
      inline: true,
      stats: 'minimal',
      contentBase: './build',
      publicPath: `/`,
      historyApiFallback: {
        rewrites: [{
          from: /^\/$/,
          to: `/`
        }, {
          from: /^\/stories\/?$/,
          to: '/stories/index.html'
        }]
      },
      before: async app => {
        const configDir = (0, _path.resolve)(__dirname, 'storybook');
        const router = await (0, _middleware.default)({
          configDir
        });
        app.use(router);
      }
    }
  };
};

exports.default = _default;