"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getAccessToken = exports.storeAccessToken = exports.generateStandardCommitMessage = exports.generateBreaking = exports.generateCloses = void 0;

var _fs = _interopRequireDefault(require("fs"));

var _path = require("path");

var _resources = require("../resources");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const generateCloses = closes => {
  let closesString = '';

  for (const close of closes) {
    closesString += `#${close}, `;
  }

  return closesString.substring(0, closesString.length - 2);
};

exports.generateCloses = generateCloses;

const generateBreaking = breaking => breaking ? 'BREAKING CHANGE' : '';

exports.generateBreaking = generateBreaking;

const generateStandardCommitMessage = // eslint-disable-next-line
(type, scope, message, closes, breaking) => ({
  title: `${type}(${scope}): ${message}`,
  description: closes.length > 0 ? `${generateCloses(closes)}\n${generateBreaking(breaking)}` : `${generateBreaking(breaking)}`
});

exports.generateStandardCommitMessage = generateStandardCommitMessage;

const storeAccessToken = token => {
  (0, _resources.addCustomResource)('.applify/githubToken', token);
};

exports.storeAccessToken = storeAccessToken;

const getAccessToken = () => {
  const applifyDir = (0, _path.join)(process.cwd(), '.applify');
  const gitTokenFile = (0, _path.join)(applifyDir, 'githubToken');

  if (_fs.default.existsSync(gitTokenFile)) {
    return _fs.default.readFileSync(gitTokenFile, 'utf8');
  }
};

exports.getAccessToken = getAccessToken;