"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.runTasks = void 0;

var _print = require("../print");

var _manager = require("../package/manager");

var _manager2 = require("../multienv/manager");

var _manager3 = require("../source/manager");

var _manager4 = require("../backend/manager");

var _npx = require("../tooling/npx");

var _babel = require("../bundle/babel");

var _readme = require("../resources/readme");

var _npx2 = require("../resources/npx");

var _babel2 = require("../resources/babel");

const taskFunctions = {
  initSourceControlManager: _manager3.initializeSourceControlManager,
  initPackageManager: _manager.initializePackageManager,
  initCommitStandard: _manager3.initializeCommitStandard,
  initGlobalBackend: _manager4.installBackendGlobally,
  initBackendManager: _manager4.initializeBackendManager,
  initMultienvManager: _manager2.initializeMultiEnvManager,
  installNpx: _npx.installNpxAndTools,
  installBabelDeps: _babel.installBabelDependencies,
  addResourceNpxScripts: _npx2.addNpxScripts,
  addResourceReadme: _readme.addReadme,
  addResourceBabelConfig: _babel2.addBabelConfig
};

const runTasks = async tasks => {
  for (const task of tasks) {
    // eslint-disable-next-line
    (0, _print.printInfo)(`\n------ ${task.description} ------\n`, true);
    await taskFunctions[task.type](...task.args);
  }
};

exports.runTasks = runTasks;